PollField enum
- Inheritance
- Implemented types
- Available extensions
Values
- id → const PollField
-
idconst PollField('id') - durationMinutes → const PollField
-
duration_minutesconst PollField('duration_minutes') - endAt → const PollField
-
end_datetimeconst PollField('end_datetime') - options → const PollField
-
optionsconst PollField('options') - votingStatus → const PollField
-
voting_statusconst PollField('voting_status')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
Returns the value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited