RateLimitExceededException class

This exception indicates that the number of requests for a particular endpoint exceeds the rate limit defined by the Twitter API.

Also, if this exception is thrown, it indicates that requests for a particular endpoint will be restricted for a certain amount of time or more.

You can see more information about rate limits here.

Inheritance

Constructors

RateLimitExceededException(String message, BaseResponse response, [String? body])
Returns the new instance of RateLimitExceededException.

Properties

body → String?
The body of the response.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String
The error message
finalinherited
response → BaseResponse
The response from the Twitter API.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited