conversationId property

String? get conversationId
inherited

The Tweet ID of the original Tweet of the conversation (which includes direct replies, replies of replies).

To obtain this field, add TweetField.conversationId in the request's query parameter.

How It Can Be Used

  • Use this to reconstruct the conversation from a Tweet.

Implementation

String? get conversationId => throw _privateConstructorUsedError;