inReplyToUserId property
If this Tweet is a Reply, indicates the user ID of the parent Tweet's author. This is returned as a string in order to avoid complications with languages and tools that cannot handle large integers.
You can obtain the expanded object in includes.users by adding
TweetExpansion.inReplyToUserId in the request's query parameter.
How It Can Be Used
- Use this to determine if this Tweet was in reply to another Tweet.
Implementation
String? get inReplyToUserId => throw _privateConstructorUsedError;