TwitterUploadException class

This class indicates that an exception occurred during a file upload to Twitter.

Inheritance

Constructors

TwitterUploadException(File file, String message, [Response? response])
Returns the new instance of TwitterUploadException.

Properties

body → String?
The body of the response.
finalinherited
file → File
The file in which the exception occurred.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
The error message
finalinherited
response → BaseResponse
The response from the Twitter API.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited