UserField enum
- Inheritance
- Implemented types
- Available extensions
Values
- id → const UserField
-
idconst UserField('id') - description → const UserField
-
descriptionconst UserField('description') - name → const UserField
-
nameconst UserField('name') - username → const UserField
-
usernameconst UserField('username') - url → const UserField
-
urlconst UserField('url') - profileImageUrl → const UserField
-
profile_image_urlconst UserField('profile_image_url') - location → const UserField
-
locationconst UserField('location') - pinnedTweetId → const UserField
-
pinned_tweet_idconst UserField('pinned_tweet_id') - protected → const UserField
-
protectedconst UserField('protected') - verified → const UserField
-
verifiedconst UserField('verified') - verifiedType → const UserField
-
verified_typeconst UserField('verified_type') - publicMetrics → const UserField
-
public_metricsconst UserField('public_metrics') - entities → const UserField
-
entitiesconst UserField('entities') - createdAt → const UserField
-
created_atconst UserField('created_at') - withheld → const UserField
-
withheldconst UserField('withheld')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
Returns the value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited