TweetMeta constructor
const
TweetMeta({})
Implementation
@JsonSerializable(includeIfNull: false)
const factory TweetMeta({
/// The Tweet ID of the most recent Tweet returned in the response.
String? newestId,
/// The Tweet ID of the oldest Tweet returned in the response.
String? oldestId,
/// The number of Tweet results returned in the response.
int? resultCount,
/// A value that encodes the next 'page' of results that can be requested,
/// via the `pagination_token` request parameter.
String? nextToken,
/// A value that encodes the previous 'page' of results that can be
/// requested, via the `pagination_token` request parameter.
String? previousToken,
}) = _TweetMeta;